==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Translate/ts/Translate_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Translate</name>
    <message>
        <location filename="../Translate.js" line="+44"/>
        <source>Modify</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Move/Copy</source>
        <translation>Sposta / Copia</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Reference point</source>
        <translation>Punto di riferimento</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_it.ts--
Punto finale
Obiettivo punto</translatorcomment>
        <translation>Obiettivo punto</translation>
    </message>
    <message>
        <location filename="../TranslateInit.js" line="+2"/>
        <source>&amp;Move / Copy</source>
        <translation>&amp;Sposta / Copia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Move or copy entities once or multiple times</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Spostare o copiare entità una volta o più volte</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Use dialog for tool options</source>
        <translation>Usa finestra di dialogo per le opzioni degli strumenti</translation>
    </message>
    <message>
        <location filename="../Translate.ui" line="+17"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies:</source>
        <translation>Numero di copie:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>Move / Copy Options</source>
        <translation type="obsolete">Opzioni Spostamento</translation>
    </message>
    <message>
        <source>Number of Copies</source>
        <translation type="obsolete">Numero di copie</translation>
    </message>
    <message>
        <source>&amp;Delete original</source>
        <translation type="obsolete">&amp;Cancella Originali</translation>
    </message>
    <message>
        <source>&amp;Keep original</source>
        <translation type="obsolete">&amp;Tieni Originali</translation>
    </message>
    <message>
        <source>&amp;Multiple copies</source>
        <translation type="obsolete">Copie &amp;Multiple</translation>
    </message>
    <message>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_it.ts--
Usa layer e gli &amp;attributi corrente</translatorcomment>
        <translation type="obsolete">Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
<context>
    <name>TranslateOptions</name>
    <message>
        <location filename="../TranslateDialog.ui" line="+14"/>
        <source>Move / Copy Options</source>
        <translation>Opzioni Spostamento</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Numero di copie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Cancella Originali</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Tieni Originali</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copie &amp;Multiple</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Translate/ts/Translate_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Translate</name>
    <message>
        <location filename="../Translate.js" line="+44"/>
        <source>Modify</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Move/Copy</source>
        <translation>Sposta / Copia</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Reference point</source>
        <translation>Punto di riferimento</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_it.ts--
Punto finale
Obiettivo punto</translatorcomment>
        <translation>Obiettivo punto</translation>
    </message>
    <message>
        <location filename="../TranslateInit.js" line="+2"/>
        <source>&amp;Move / Copy</source>
        <translation>&amp;Sposta / copia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Move or copy entities once or multiple times</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Spostare o copiare entità una volta o più volte</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Use dialog for tool options</source>
        <translation>Usa finestra di dialogo per le opzioni degli strumenti</translation>
    </message>
    <message>
        <location filename="../Translate.ui" line="+17"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies:</source>
        <translation>Numero di copie:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>Move / Copy Options</source>
        <translation type="obsolete">Opzioni Spostamento</translation>
    </message>
    <message>
        <source>Number of Copies</source>
        <translation type="obsolete">Numero di copie</translation>
    </message>
    <message>
        <source>&amp;Delete original</source>
        <translation type="obsolete">&amp;Cancella Originali</translation>
    </message>
    <message>
        <source>&amp;Keep original</source>
        <translation type="obsolete">&amp;Tieni Originali</translation>
    </message>
    <message>
        <source>&amp;Multiple copies</source>
        <translation type="obsolete">Copie &amp;Multiple</translation>
    </message>
    <message>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_it.ts--
Usa layer e gli &amp;attributi corrente</translatorcomment>
        <translation type="obsolete">Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
<context>
    <name>TranslateOptions</name>
    <message>
        <location filename="../TranslateDialog.ui" line="+14"/>
        <source>Move / Copy Options</source>
        <translation>Opzioni Spostamento</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Numero di copie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Cancella Originali</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Tieni Originali</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copie &amp;Multiple</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Usa layer e gli &amp;attributi corrente</translation>
    </message>
</context>
</TS>
